summaryrefslogtreecommitdiff
path: root/dns/inet.py
diff options
context:
space:
mode:
authorBob Halley <halley@dnspython.org>2020-05-08 07:02:48 -0700
committerBob Halley <halley@dnspython.org>2020-05-08 07:02:48 -0700
commitc8484ecb460ef90a9db6d32eef09542d3e850c57 (patch)
treee27ee464c97472d21e393fa234a7db9af5946423 /dns/inet.py
parent91adcbf570bf5e00373ae47ceee0cefe684d5b70 (diff)
downloaddnspython-c8484ecb460ef90a9db6d32eef09542d3e850c57.tar.gz
in doco, text->str, binary->bytes
Diffstat (limited to 'dns/inet.py')
-rw-r--r--dns/inet.py12
1 files changed, 6 insertions, 6 deletions
diff --git a/dns/inet.py b/dns/inet.py
index a1e8f64..a1b0c3e 100644
--- a/dns/inet.py
+++ b/dns/inet.py
@@ -41,12 +41,12 @@ def inet_pton(family, text):
*family* is an ``int``, the address family.
*text* is a ``text``, the textual address.
Raises ``NotImplementedError`` if the address family specified is not
implemented.
- Returns a ``binary``.
+ Returns a ``bytes``.
"""
if family == AF_INET:
@@ -62,12 +62,12 @@ def inet_ntop(family, address):
*family* is an ``int``, the address family.
*address* is a ``binary``, the network address in binary form.
Raises ``NotImplementedError`` if the address family specified is not
implemented.
- Returns a ``text``.
+ Returns a ``str``.
"""
if family == AF_INET:
@@ -81,7 +81,7 @@ def inet_ntop(family, address):
def af_for_address(text):
"""Determine the address family of a textual-form network address.
*text*, a ``text``, the textual address.
Raises ``ValueError`` if the address family cannot be determined
from the input.
@@ -103,7 +103,7 @@ def af_for_address(text):
def is_multicast(text):
"""Is the textual-form network address a multicast address?
*text*, a ``text``, the textual address.
Raises ``ValueError`` if the address family cannot be determined
from the input.
@@ -41,12 +41,12 @@ def inet_pton(family, text):
*family* is an ``int``, the address family.
- *text* is a ``text``, the textual address.
+ *text* is a ``str``, the textual address.
Raises ``NotImplementedError`` if the address family specified is not
implemented.
@@ -62,12 +62,12 @@ def inet_ntop(family, address):
*family* is an ``int``, the address family.
- *address* is a ``binary``, the network address in binary form.
+ *address* is a ``bytes``, the network address in binary form.
Raises ``NotImplementedError`` if the address family specified is not
implemented.
@@ -81,7 +81,7 @@ def inet_ntop(family, address):
def af_for_address(text):
"""Determine the address family of a textual-form network address.
- *text*, a ``text``, the textual address.
+ *text*, a ``str``, the textual address.
Raises ``ValueError`` if the address family cannot be determined
from the input.
@@ -103,7 +103,7 @@ def af_for_address(text):
def is_multicast(text):
"""Is the textual-form network address a multicast address?
- *text*, a ``text``, the textual address.
+ *text*, a ``str``, the textual address.
Raises ``ValueError`` if the address family cannot be determined
from the input.